==> financial-settlement-service-0.1.273-sources.jar: com/xforceplus/ultraman/app/financialsettlement/controller/BillDetailController.java <==
package com.xforceplus.ultraman.app.financialsettlement.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.financialsettlement.entity.BillDetail;
import com.xforceplus.ultraman.app.financialsettlement.service.IBillDetailService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 结算单明细表-税号前端控制器
 *
 * @author ultraman
 * @date 2022-09-29
 */
@RestController
public class BillDetailController {

  @Autowired
  private IBillDetailService billDetailServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param billDetail 结算单明细表-税号
   * @return
   */
  @GetMapping("/billdetails" )
  public XfR getBillDetails(XfPage page, BillDetail billDetail) {
    return XfR.ok(billDetailServiceImpl.page(page, Wrappers.query(billDetail)));
  }

  /**
   * 通过id查询结算单明细表-税号
   * @param  id
   * @return XfR
   */
  @GetMapping("/billdetails/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(billDetailServiceImpl.getById(id));
  }

  /**
   * 新增结算单明细表-税号
   * @param billDetail 结算单明细表-税号
   * @return XfR
   */
  @PostMapping("/billdetails")
  public XfR save(@RequestBody BillDetail billDetail) {
     return XfR.ok(billDetailServiceImpl.save(billDetail));
  }

  /**
   * 修改-传入修改后的全部数据结算单明细表-税号
   * @param billDetail 结算单明细表-税号
   * @return XfR
   */
  @PutMapping("/billdetails/{id}")
  public XfR putUpdate(@RequestBody BillDetail billDetail,@PathVariable Long id) {
      billDetail.setId(id);
      return XfR.ok(billDetailServiceImpl.updateById(billDetail));
  }

  /**
   * 修改-传入修改的数据结算单明细表-税号
   * @param billDetail 结算单明细表-税号
   * @return XfR
   */
  @PatchMapping("/billdetails/{id}")
  public XfR patchUpdate(@RequestBody BillDetail billDetail,@PathVariable Long id) {
      BillDetail upbillDetail = billDetailServiceImpl.getById(id);
      if(upbillDetail != null){
        upbillDetail = ObjectCopyUtils.copyProperties(billDetail,upbillDetail,true);
      }
      return XfR.ok(billDetailServiceImpl.updateById(upbillDetail));
  }

  /**
   * 通过id删除结算单明细表-税号
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/billdetails/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(billDetailServiceImpl.removeById(id));
  }

  @PostMapping("/billdetails/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "bill_detail");
     params.put("request", condition);

     return XfR.ok(billDetailServiceImpl.querys(params));
  }

}

==> financial-settlement-service-0.1.318-sources.jar: com/xforceplus/ultraman/app/financialsettlement/controller/BillDetailController.java <==
package com.xforceplus.ultraman.app.financialsettlement.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.financialsettlement.entity.BillDetail;
import com.xforceplus.ultraman.app.financialsettlement.service.IBillDetailService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 结算单明细表-税号前端控制器
 *
 * @author ultraman
 * @date 2023-03-08
 */
@RestController
public class BillDetailController {

  @Autowired
  private IBillDetailService billDetailServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param billDetail 结算单明细表-税号
   * @return
   */
  @GetMapping("/billdetails" )
  public XfR getBillDetails(XfPage page, BillDetail billDetail) {
    return XfR.ok(billDetailServiceImpl.page(page, Wrappers.query(billDetail)));
  }

  /**
   * 通过id查询结算单明细表-税号
   * @param  id
   * @return XfR
   */
  @GetMapping("/billdetails/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(billDetailServiceImpl.getById(id));
  }

  /**
   * 新增结算单明细表-税号
   * @param billDetail 结算单明细表-税号
   * @return XfR
   */
  @PostMapping("/billdetails")
  public XfR save(@RequestBody BillDetail billDetail) {
     return XfR.ok(billDetailServiceImpl.save(billDetail));
  }

  /**
   * 修改-传入修改后的全部数据结算单明细表-税号
   * @param billDetail 结算单明细表-税号
   * @return XfR
   */
  @PutMapping("/billdetails/{id}")
  public XfR putUpdate(@RequestBody BillDetail billDetail,@PathVariable Long id) {
      billDetail.setId(id);
      return XfR.ok(billDetailServiceImpl.updateById(billDetail));
  }

  /**
   * 修改-传入修改的数据结算单明细表-税号
   * @param billDetail 结算单明细表-税号
   * @return XfR
   */
  @PatchMapping("/billdetails/{id}")
  public XfR patchUpdate(@RequestBody BillDetail billDetail,@PathVariable Long id) {
      BillDetail upbillDetail = billDetailServiceImpl.getById(id);
      if(upbillDetail != null){
        upbillDetail = ObjectCopyUtils.copyProperties(billDetail,upbillDetail,true);
      }
      return XfR.ok(billDetailServiceImpl.updateById(upbillDetail));
  }

  /**
   * 通过id删除结算单明细表-税号
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/billdetails/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(billDetailServiceImpl.removeById(id));
  }

  @PostMapping("/billdetails/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "bill_detail");
     params.put("request", condition);

     return XfR.ok(billDetailServiceImpl.querys(params));
  }

}
